#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gmodule
version:                2.0.6
visibility:             public
id:                     gi-gmodule-2.0.6-K14pVBc8YfgIyRVXMaW8ye
key:                    gi-gmodule-2.0.6-K14pVBc8YfgIyRVXMaW8ye
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               GModule bindings
description:            Bindings for GModule, autogenerated by haskell-gi.
category:               Bindings
abi:                    2dab90a07d37994d3308d6c80e98f8f0
exposed:                True
exposed-modules:
    GI.GModule GI.GModule.Callbacks GI.GModule.Config
    GI.GModule.Constants GI.GModule.Enums GI.GModule.Flags
    GI.GModule.Structs GI.GModule.Structs.Module

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gmodule-2.0.6
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-gmodule-2.0.6 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-gmodule-2.0.6 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gmodule
hs-libraries:           HSgi-gmodule-2.0.6-K14pVBc8YfgIyRVXMaW8ye
extra-libraries:        gmodule-2.0 glib-2.0
extra-libraries-static:
    gmodule-2.0 glib-2.0 atomic m sysprof-capture-4 pcre2-8 pthread

include-dirs:
    /usr/include /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-glib-2.0.30-7nzdd2SAfr97nYfgYpanzg
    haskell-gi-0.26.16-DnzPEJELAqJ2SnrzEtuKAT
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

ld-options:             "-Wl,--export-dynamic" -pthread
haddock-interfaces:     /usr/share/doc/haskell-gi-gmodule/html/gi-gmodule.haddock
haddock-html:           /usr/share/doc/haskell-gi-gmodule/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

